@@ -227,6 +227,8 @@ def make_space(space_name, store, member):
 
     info_tiddler = Tiddler('SiteInfo', space.public_bag())
     info_tiddler.text = 'Space %s' % space_name
+    info_tiddler.modifier = store.environ.get('tiddlyweb.usersign',
+            {}).get('name', 'GUEST')
     store.put(info_tiddler)
 
     # Duplicate GettingStarted into public bag.
